@@ -14,14 +14,21 @@ dateformat="%Y-%m-%d %H:%M:%S" #the date/time is stored in this format in the re
 
 
 
-UIStyle=""
-
-
 
 DisplayIsOn=True
 
 
 
+GraphBitMap=""
+GraphBitMapLen=0
+GraphBitMapHeight=0
+
+DisplayIsOn=True
+ScrollToEnd=False
+
+
+
+
 #init values
 Sampling_interval=1000 #in milliseconds
 Sample_index=0
@@ -52,7 +59,7 @@ logfile=""
 logfolder=""
 lastlogfile=""
 
-ChangesInGraph=False
+#ChangesInGraph=False
 run=False
 QuickMode=False
 version="0"
@@ -71,7 +78,7 @@ SilentProfile=False
 PreviouseProfile="silent"
 DelayStart=0
 interval=0
-GraphStart=0
+#GraphStart=0
 #GraphStartHours=0
 #GraphStartMinutes=0
 #AlarmTimeSec=0 #absolute alarm time in seconds
