@@ -133,47 +133,48 @@ def ProcessData(ProcessAll=False):  #DERIVATION (ABLEITUNG)
 ## Show (refreshs) the graph.
 ## the first parameter indcates on which window it will be drawn
 ###########################################################################
-def showGraph(self,  QtGui):
-    if(data.ChangesInGraph==False): 
-        if(data.debug==1): print "-> Do not redraw, nothing changed!"
-        return 
-    if(data.DisplayIsOn==False):
-        if(data.debug==1): print "-> Do not redraw, Display is off!"
-        return
-        
-        
-#    print "Show data of file",  data.logfilename
-#    print "----------------------------"
-    ScrollbarStartPercent, ScrollbarEndPercent=ScrollbarData()
+def GenerateGraph(self,  QtGui):
+
     Xscale=data.arrXscale[data.Xscale]
     decade=360/Xscale
+    
+#    data.GraphStart=0
+    
+#    GraphSize=max(data.GraphBitMapLen+2, 785)
 
 #        print "-----------------------------------"
 #        print "Xscale:",  Xscale
 #        print "Current index:",  records.Index
 #        print "LastIndex:",  records.LastIndex
-#        print "GraphLen (WindowSize):",  data.GraphLen
+#        print "data.GraphBitMapLen (WindowSize):",  data.data.GraphBitMapLen
 #        print "GraphStart:",  data.GraphStart
 #        print "GraphEnd:",  data.GraphEnd
 #        print "The area between index",data.GraphStart , "and",data.GraphEnd , "will be shown"
 #        print "Scrollbar:",  ScrollbarStartPercent, "...", ScrollbarEndPercent, "%"
     
-#        print "Shown graph is from index",  data.GraphStart,  "to",  data.GraphStart+GraphLen
+#        print "Shown graph is from index",  data.GraphStart,  "to",  data.GraphStart+data.GraphBitMapLen
         
 #    PrintRecordData()
 
 #    print "data.QuickMode:",  data.QuickMode
         
-    data.ChangesInGraph=False
+#    data.ChangesInGraph=False
     paint = QtGui.QPainter()
     paint.begin(self)
 
     paint.setFont(QtGui.QFont('Decorative', 12))
     
-    #show Graph border 
-    paint.setPen(QtGui.QColor("white"))
-    paint.setBrush(QtGui.QColor("black"))    
-    paint.drawRect(0,0,781,data.Ysize)    
+    #clear whole pitmap (remove old data)
+    paint.setPen(QtGui.QColor("#101010"))
+    paint.setBrush(QtGui.QColor("#101010"))    
+    paint.drawRect(0,0,data.GraphBitMapLen,data.GraphBitMapHeight)   
+    
+    
+#    #show Graph border 
+##    paint.setPen(QtGui.QColor("white"))
+##    paint.setBrush(QtGui.QColor("#101010"))    
+###    paint.drawRect(0,0,781,data.Ysize)    
+##    paint.drawRect(0,0,data.GraphBitMapLen,data.Ysize)   
 
     #Stop if data is not ok
     if(records.statusID!="OK"):#Show useful infos                 
@@ -183,7 +184,8 @@ def showGraph(self,  QtGui):
         return
     
     
-    GraphStart_tuple=Index2Tuple(data.GraphStart)
+#    GraphStart_tuple=Index2Tuple(data.GraphStart)
+    GraphStart_tuple=Index2Tuple(0) #time of first record entry
 #    if(data.debug==1): print "data.GraphStart",  data.GraphStart,  GraphStart_tuple
     h=int(strftime("%H", GraphStart_tuple))
     m=int(strftime("%M", GraphStart_tuple))
@@ -196,8 +198,8 @@ def showGraph(self,  QtGui):
     LastFullHour_tuple=Seconds2Tuple(LastFullHour_sec)
     
     h0=int(strftime("%H", LastFullHour_tuple))
-    m0=int(strftime("%M", LastFullHour_tuple))
-    s0=int(strftime("%S", LastFullHour_tuple))
+    m0=0 #int(strftime("%M", LastFullHour_tuple))
+    s0=0# int(strftime("%S", LastFullHour_tuple))
 #    print h0,  m0,  s0
     
     
@@ -206,25 +208,38 @@ def showGraph(self,  QtGui):
     
     LastFullHour_index=Tuple2Index(LastFullHour_tuple)
 
-    GraphStart_index=Tuple2Index(GraphStart_tuple) #should be same as data.GraphStart, but is not due rounding
+    GraphStart_index=Tuple2Index(GraphStart_tuple) 
 #    print "Indexes:",  GraphStart_index,  "(",  data.GraphStart, ")",  LastFullHour_index
-    
-    OffsetToLastFullHour=-1*(GraphStart_index-LastFullHour_index)/Xscale 
-    OffsetToLastFullHour=OffsetToLastFullHour-data.Derivation/Xscale  #Derivation takes 5 idnices, so visualisation is delayed!
 
+    OffsetToLastFullHour=-1*(GraphStart_index - LastFullHour_index)/Xscale 
+    OffsetToLastFullHour=OffsetToLastFullHour- data.Derivation/Xscale  #Derivation takes 5 indices, so visualisation is delayed!
+    
+#    print "OffsetToLastFullHour:",  OffsetToLastFullHour,  "GraphStart_index:",  GraphStart_index,  "LastFullHour_index:",  LastFullHour_index
+    
 #    print "Last data is on:",  Index2Tuple(records.Index)
     
+    
+    
+    
+    
+    
+    
     #DRAW main scaling lines + text        
     paint.setPen(QtGui.QColor("white"))
     if(data.QuickMode==False): #normal mode
 #        print "OffsetToLastFullHour:",  OffsetToLastFullHour
         if(data.Xscale==0): #max zoom
-            for i in range(OffsetToLastFullHour-decade, 781+decade,  decade): #full hours
+#            for i in range(OffsetToLastFullHour-decade, 781+decade,  decade): #full hours
+#            for i in range(0, data.GraphBitMapLen,  decade): #full hours
+            for i in range(OffsetToLastFullHour-decade, max(data.GraphBitMapLen, records.Index)+decade,  decade): #full hours
                 h=(h0+int(i/decade)+1) % 24
 #                print i
                 paint.drawLine(i, data.Ysize, i, data.Ysize+10) 
                 paint.setFont(QtGui.QFont('Decorative', 18))
-                paint.drawText(i-15, data.Ysize+30, str(h))
+                paint.drawText(i-25, data.Ysize+32, str(h)+":00")
+#                #show dashed line
+#                paint.drawLine(i, 0, i, data.Ysize) 
+                
                 paint.setFont(QtGui.QFont('Decorative', 12))
                 for k in range(1, 6): #hour + k * 10 minutes
                     x=i+k*decade/6
@@ -237,41 +252,34 @@ def showGraph(self,  QtGui):
                     paint.drawLine(x2, data.Ysize, x2, data.Ysize+4) 
 
         elif(data.Xscale==1 or data.Xscale==2): #mid + min zoom
-            for i in range(OffsetToLastFullHour-decade, 781+decade,  decade): #full hours
+#            for i in range(OffsetToLastFullHour-decade, 781+decade,  decade): #full hours
+            for i in range(OffsetToLastFullHour-decade, max(data.GraphBitMapLen, records.Index)+decade,  decade): #full hours
                 h=(h0+int(i/decade)+1) % 24
 #                print i
                 paint.drawLine(i, data.Ysize, i, data.Ysize+10) 
                 paint.drawText(i-15, data.Ysize+30, str(h)+":00")
+                
+#                #show dashed line
+#                paint.setPen(QtGui.QColor("grey"))
+#                paint.drawLine(i, 0, i, data.Ysize) 
+                
                 for k in range(1, 6): #hour + k * 10 minutes
                     x=i+k*decade/6
 #                    print " ", x,  str(h)+":"+str(10*k)
                     paint.drawLine(x, data.Ysize, x, data.Ysize+4)  
 
     else: #quick mode, do not show X scale as it is not calibrated
-        paint.drawText(200, data.Ysize+20, "Test Mode, no scale available")
-    
-
-    
-
-    #DRAW scroll bar 
-    if(ScrollbarStartPercent>0 or ScrollbarEndPercent<100):
-        paint.setPen(QtGui.QColor("gray"))
-        paint.drawRect(0,data.Ysize+37,779,7)
-        paint.setPen(QtGui.QColor("white"))
-        paint.setBrush(QtGui.QColor("white"))
-#        print ScrollbarStartPercent,  ScrollbarEndPercent
-        x0=int(779*math.floor(ScrollbarStartPercent)/100)
-        x1=int(779*math.ceil(ScrollbarEndPercent)/100)
-#        print x0,  x1
-        paint.drawRect(x0,  data.Ysize+38, x1-x0 ,  5)
-
+#        paint.drawText(200, data.Ysize+20, "Test Mode, no time scale available")
+#        paint.drawText((max(data.GraphBitMapLen, records.Index)-500)/Xscale, data.Ysize+20, "Test Mode, no time scale available")
+        pass
 
 
 
     #DRAW time bars
     start=GraphStart_index % 6
     lastmoveovertrigger=start
-    for p in range(start,  records.Index-data.Derivation):
+#    for p in range(start,  records.Index-data.Derivation):
+    for p in range(0,  records.Index-data.Derivation):
         if(records.arrData[3][p]>data.Trigger or p>records.Index-data.Derivation-2):
             x0=(lastmoveovertrigger-GraphStart_index)/Xscale
             x1=(p-GraphStart_index)/Xscale
@@ -299,9 +307,10 @@ def showGraph(self,  QtGui):
     #DRAW graph
     paint.setPen(QtGui.QColor("yellow"))           
     peak=0
-    for p in range(GraphStart_index,  records.Index-data.Derivation,  Xscale):
+#    for p in range(GraphStart_index,  records.Index-data.Derivation,  Xscale):
+    for p in range(0,  records.Index-data.Derivation,  Xscale):
         i=p-GraphStart_index
-        if(i>779*Xscale): break
+#        if(i>779*Xscale): break
         #when Xscale is small, we have to merge several records into 1 pixel.
         #Too not miss any movement, we use the biggest movement of the merged records:
         peak=0            
@@ -314,7 +323,7 @@ def showGraph(self,  QtGui):
         paint.drawLine(x, data.Ysize-h-1-15, x, data.Ysize-1-15)  #draw yellow movement bar
         
         if(peak>data.Trigger):
-            paint.setPen(QtGui.QColor("black"))
+            paint.setPen(QtGui.QColor("#101010"))
             paint.drawLine(x, data.Ysize-11, x, data.Ysize-1)  #draw yellow movement bar
             paint.setPen(QtGui.QColor("yellow"))
 #            print "Peak:", i,  x
@@ -323,73 +332,6 @@ def showGraph(self,  QtGui):
 
 
 
-
-
-
-        #draw time bars
-#        if(peak>records.Trigger): 
-#        if(peak>data.Trigger): 
-#            x0=max(lastmovebeforegraph/Xscale+1, 0)
-#            if(x0==1):  x0=0
-#            x1=i/Xscale-1
-#            print i,  (x1-x0)*Xscale/6 
-#            if(x0<x1): 
-#                    t=(x1-x0)*Xscale/6          
-#                    if(t>30): color="#009100" #green
-#                    elif(t>15): color="#005000" #dark green
-#                    elif(t>7): color="#97320e" #orange
-#                    else: color="#6D0000" #dark red                   
-#                    paint.setBrush(QtGui.QColor(color))
-#                    paint.setPen(QtGui.QColor(color))
-#                    paint.drawRect(x0+1, data.Ysize-11, x1-x0-1, 10)                     
-#                    paint.setPen(QtGui.QColor("yellow"))
-##            lastdatapoint=p # used for last time bar
-#            lastdatapoint=i # used for last time bar
-#            lastmovebeforegraph=i
-#            
-#            
-            
-            
-            
-    # Draw very last time bar
-#    firstmoveaftergraph=records.Index
-#    for p in range(lastdatapoint, records.Index):
-#        if(records.arrData[3][p]>data.Trigger): 
-#            firstmoveaftergraph=p-GraphStart_index
-#            break
-#    x1=(firstmoveaftergraph-GraphStart_index)/Xscale
-#    x0=(lastdatapoint-GraphStart_index)/Xscale+1
-#    x1=(records.Index-GraphStart_index-data.Derivation)/Xscale
-#    print x0,  x1,  (x1-x0)*Xscale/6   
-#    if(x0<x1):
-#        t=(x1-x0)*Xscale/6          
-#        if(t>30): color="#009100" #green
-#        elif(t>15): color="#005000" #dark green
-#        elif(t>7): color="#97320e" #orange
-#        else: color="#6D0000" #dark red                   
-#        paint.setBrush(QtGui.QColor(color))
-#        paint.setPen(QtGui.QColor(color))                    
-#        x1=min(779, x1)
-#        paint.drawRect(x0+1, data.Ysize-11, x1-x0-1, 10)   
-        
-        
-        
-        
-    #check if at least one time bar is drawn
-#    if(lastmovebeforegraph==0): #no interuption in whole graph
-#        x0=0
-#        x1=(records.Index-GraphStart_index-data.Derivation)/Xscale
-#        if(x0<x1):
-#            t=(x1-x0)*Xscale/6          
-#            if(t>30): color="#009100" #green
-#            elif(t>15): color="#005000" #dark green
-#            elif(t>7): color="#97320e" #orange
-#            else: color="#6D0000" #dark red                  
-#            paint.setBrush(QtGui.QColor(color))
-#            paint.setPen(QtGui.QColor(color))                    
-#            paint.drawRect(x0+1, data.Ysize-11, x1-x0-1, 10)   
-        
-        
         
     
    #ALARM VISUALISATION
@@ -440,25 +382,25 @@ def showGraph(self,  QtGui):
         if(data.run==False):  #show trigger level stored in record
             paint.setPen(QtGui.QColor("gray"))
             y=(data.Ysize-(records.Trigger*data.Yscale/2))-2
-            paint.drawLine(1, y-15, 781, y-15)  #Trigger line
-            paint.drawText(760, y-17, str(records.Trigger)) #Trigger level
+            paint.drawLine(1, y-15, data.GraphBitMapLen-2, y-15)  #Trigger line
+            paint.drawText(data.GraphBitMapLen-25, y-17, str(records.Trigger)) #Trigger level
 #            paint.drawText(5, 15, str(data.Yscale)) #Y scale
         paint.setPen(QtGui.QColor("white"))
         y=(data.Ysize-(data.Trigger*data.Yscale/2))-2
-        paint.drawLine(1, y-15, 781, y-15)  #Trigger line
-        paint.drawText(760, y-17, str(data.Trigger)) #Trigger level
+        paint.drawLine(1, y-15, data.GraphBitMapLen-2, y-15)  #Trigger line
+        paint.drawText(data.GraphBitMapLen-25, y-17, str(data.Trigger)) #Trigger level
 #        paint.drawText(5, 15, str(data.Yscale)) #Y scale
        
        
        
-    #redraw border in case it got over drawn
+    #Draw border around it
     paint.setPen(QtGui.QColor("white"))
-    paint.drawLine(0, 0, 0, data.Ysize)  #left side
-    paint.drawLine(781, 0, 781, data.Ysize)  #right side
-    paint.drawLine(0, 0, 781, 0)  #top
-    paint.drawLine(0, data.Ysize, 781, data.Ysize)  #bottom
+    paint.drawLine(0, 0, 0, data.Ysize)  #left side    
+    paint.drawLine(data.GraphBitMapLen-1, 0, data.GraphBitMapLen-1, data.Ysize)  #right side
+    paint.drawLine(0, 0, data.GraphBitMapLen-1, 0)  #top
+    paint.drawLine(0, data.Ysize, data.GraphBitMapLen-1, data.Ysize)  #bottom
+
 
-       
        
     #beep in test mode
     if(peak>data.Trigger): #if last value is over peak
@@ -470,30 +412,34 @@ def showGraph(self,  QtGui):
                 b.close()
 
 
+    paint.end()
 
 
 
 
-###########################################################################
-## 
-###########################################################################  
-def ScrollbarData():        
-    Xscale=data.arrXscale[data.Xscale]
-    data.GraphLen=(records.LastIndex+5)/Xscale
-    if(data.GraphLen==0): data.GraphLen=1 #prevent divisions by zero
-    data.GraphEnd=min(records.LastIndex+5,  data.GraphStart+779*Xscale-data.Derivation)
-    
-    if(data.GraphEnd<=data.Derivation): return [0,  100]
-    
-    p0=float(data.GraphStart)*100/data.GraphLen/Xscale
-    p1=float(data.GraphEnd)*100/data.GraphLen/Xscale
-    p1=min(100,  p1)
-#    print "--------------------"
-#    print "Scroll bar is on %:", p0, "...", p1 
-#    print "records.LastIndex:",  records.LastIndex
-#    print "data.GraphLen:",  data.GraphLen
-#    print "data.GraphEnd:",  data.GraphEnd
-    return [p0,  p1]
+
+
+
+############################################################################
+### 
+############################################################################  
+#def ScrollbarData():        
+#    Xscale=data.arrXscale[data.Xscale]
+#    data.data.GraphBitMapLen=(records.LastIndex+5)/Xscale
+#    if(data.data.GraphBitMapLen==0): data.data.GraphBitMapLen=1 #prevent divisions by zero
+#    data.GraphEnd=min(records.LastIndex+5,  data.GraphStart+779*Xscale-data.Derivation)
+#    
+#    if(data.GraphEnd<=data.Derivation): return [0,  100]
+#    
+#    p0=float(data.GraphStart)*100/data.data.GraphBitMapLen/Xscale
+#    p1=float(data.GraphEnd)*100/data.data.GraphBitMapLen/Xscale
+#    p1=min(100,  p1)
+##    print "--------------------"
+##    print "Scroll bar is on %:", p0, "...", p1 
+##    print "records.LastIndex:",  records.LastIndex
+##    print "data.data.GraphBitMapLen:",  data.data.GraphBitMapLen
+##    print "data.GraphEnd:",  data.GraphEnd
+#    return [p0,  p1]
 
 
 
