@@ -61,7 +61,6 @@ from Ui_AdditionalInfoWindow import *
 def main():
     global app,  StartWindow,  RecordWindow,  ViewWindow ,  ConfigWindow,  DateWindow,  AlarmTimeWindow,  AskForKeepWindow,  AdditionalInfoWindow,  HelpWindow
     global config
-    global RecordWindowGraph
    
     try:
         if(sys.argv[1]=="debug"): 
@@ -172,7 +171,6 @@ def EditUserName():
 ##  Gets called every second
 ###########################################################################
 def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothing)
-    global RecordWindowGraph    
     r=GetSensorData()     
     if(r==1): #new data got added to array
         ProcessData(False)      
@@ -181,10 +179,10 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
         WriteIntoRecordFile()
         
         GraphLen=records.Index/data.arrXscale[data.Xscale]
-        data.GraphStart=max(GraphLen-779, 0)
+#        data.GraphStart=max(GraphLen-779, 0)
         
-        data.ChangesInGraph=True #Make sure it only gets refreshed once
-        RecordWindowGraph.update() #show RecordWindowGraph          
+        data.ScrollToEnd=True
+        ShowGraph(RecordWindow)    
     
         if(records.Index==records.MaxArrayDataLen-1): 
             print "Stopped, array is full"
@@ -192,6 +190,7 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
             QtGui.QMessageBox.warning(RecordWindow, 'Memory is full!', "You reached the end of the recording capacity (24h)!\nThe recording stops now.", QtGui.QMessageBox.Ok)
 #            RecordWindow.StopMeasurement()
             StopMeasurement() #but keep alarm active!
+    
     RecordWindow.UpdateScreen()      
   
 #    print data.AlarmIsActive,  data.StopAfterAlarm
@@ -204,17 +203,15 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
   
 
 
-
-
-
 ###########################################################################
 ## Start the measurement
 ###########################################################################
 def InitMeasurement():
-    global app,  RecordWindowGraph
+    global app
 
     data.sample_index=0
-    data.Status="Recording..."
+    if(data.QuickMode==False): data.Status="Recording..."
+    else: data.Status="Recording in Test Mode..."
 
     records.User=data.user
     records.SWversion=data.version
@@ -237,7 +234,41 @@ def InitMeasurement():
 #    print "#################### USE MAXIMUM SPEED FOR DEBUGGING!!!!!!!!!!!"
 #    data.interval=1 #Debugging
     
-    #change to offline mode and silent profile if requested
+   
+
+    data.run=True #change to recording
+    app.timer_GetData = QtCore.QTimer()
+    QtCore.QObject.connect(app.timer_GetData, QtCore.SIGNAL("timeout()"), MeasurementTimerLoop)     
+
+    data.StartTime=time.localtime()
+    data.StartTimeSec=Tuple2Seconds(data.StartTime)
+   
+    if(data.debug==False): app.timer_GetData.start(data.interval)   
+    else: app.timer_GetData.start(1)    #run very fast for testing
+    
+    CreateRecordFile(data.interval)
+    GetFirstEntry()
+    WriteIntoRecordFile()
+   
+    ShowGraph(RecordWindow)
+    RecordWindow.UpdateScreen()
+    
+    RecordWindow.ui.CanvasWidget.show()
+    RecordWindow.UpdateScreen()
+    
+    
+
+    if(data.debug==1): 
+        print "Start timers (Interval:", data.interval ,"ms)..."
+        print "Sampling interval:", data.interval, "ms"
+        print "sample_smoothing:", data.Sample_smoothing, "x"
+        print "value_smoothing:", data.Value_smoothing, "x"
+        print "=> log interval:", data.interval*data.Value_smoothing, "ms"
+        print "Derivation:", data.Derivation, "(substracts value", data.Derivation, "- value 0)"  
+    
+    
+    
+     #change to offline mode and silent profile if requested
     if(data.demo==False): #We are on a N900
         if(data.QuickMode==False):
             if(data.OfflineMode==True): #change to offline mode
@@ -269,35 +300,6 @@ def InitMeasurement():
                         os.popen(cmd)
                 except:
                     pass   
-
-    data.run=True #change to recording
-    app.timer_GetData = QtCore.QTimer()
-    QtCore.QObject.connect(app.timer_GetData, QtCore.SIGNAL("timeout()"), MeasurementTimerLoop)     
-
-    data.StartTime=time.localtime()
-    data.StartTimeSec=Tuple2Seconds(data.StartTime)
-   
-    if(data.debug==False): app.timer_GetData.start(data.interval)   
-    else: app.timer_GetData.start(1)    #run very fast for testing
-    
-    CreateRecordFile(data.interval)
-    GetFirstEntry()
-    WriteIntoRecordFile()
-#    WriteFirstEntryIntoRecordFile() #write first entry
-   
-    data.ChangesInGraph=True #Make sure it only gets refreshed once    
-    RecordWindowGraph.update() #show RecordWindowGraph        
-    RecordWindow.UpdateScreen()
-
-    if(data.debug==1): 
-        print "Start timers (Interval:", data.interval ,"ms)..."
-        print "Sampling interval:", data.interval, "ms"
-        print "sample_smoothing:", data.Sample_smoothing, "x"
-        print "value_smoothing:", data.Value_smoothing, "x"
-        print "=> log interval:", data.interval*data.Value_smoothing, "ms"
-        print "Derivation:", data.Derivation, "(substracts value", data.Derivation, "- value 0)"  
-    
-    
     
     
     
@@ -450,21 +452,17 @@ class frmStartWindow(QMainWindow):
         
         
     def StartMeasurement(self):
-        global RecordWindowGraph
         RecordWindow.show()
-        RecordWindowGraph = RecordWindowCanvas(RecordWindow)
         InitRecord() #clear all old data
         InitMeasurement()
         RecordWindow.UpdateScreenStart()
-        RecordWindowGraph.show()
+        RecordWindow.Canvas.show()
         
         
     ###########################################################################
     ## Show the log window (where the data from a file gets visualised)
     ###########################################################################
-    def ShowViewWindow(self):
-        global ViewWindowGraph       ,  WidgetGraph
-        
+    def ShowViewWindow(self):        
         #reset to default log folder
         if(data.demo==True): data.logfolder=data.devlogfolder #folder on devel PC
         else: data.logfolder=data.defaultlogfolder
@@ -487,15 +485,6 @@ class frmStartWindow(QMainWindow):
                 data.logfolder=string.replace(tmp,  data.logfilename,  "") #get folder of selected file
                 print "Set folder=",  data.logfolder,  ", file=",  data.logfilename
         
-        ViewWindowGraph = ViewWindowCanvas(self)
-#        ViewWindowGraph = ViewWindowCanvas(ViewWindow.ui.WidgetGraph)
-#        ViewWindowGraph = ViewWindowCanvas(ViewWindow.ui.scrollAreaWidgetContents)
-#        ViewWindowGraph.setGeometry(QtCore.QRect(0, 0, 1000, 500))
-#        ViewWindow.ui.horizontalLayout.addWidget(ViewWindowGraph)
-
-#        ViewWindow.ui.lblTest = QtGui.QLabel(ViewWindow.ui.WidgetGraph)
-#        ViewWindow.ui.lblTest.setGeometry(QtCore.QRect(0, 0, 100, 50))
-        
         
         ViewWindow.ShowLogFile()
         
@@ -578,13 +567,23 @@ class frmStartWindow(QMainWindow):
 #  Class for Collecting Window
 ###########################################################################
 class frmRecordWindow(QMainWindow):
-    def __init__(self, parent=None):        
+    def __init__(self, parent=None):       
         QMainWindow.__init__(self, parent) # Notice that you must give a parent window as parameter to the constuctor
         if(data.demo==False): self.setAttribute(Qt.WA_Maemo5StackedWindow) # Also set the Stacked Window parameter for every subwindow in the stack
         
         self.ui = Ui_RecordWindow()
         self.ui.setupUi(self)
         
+#        scroller = self.ui.ScrollArea.property("kineticScroller").toPyObject()
+#        scroller.setEnabled(True)
+        
+        self.Canvas = MyCanvas(self.ui.CanvasWidget)
+        
+        self.ui.CanvasWidget.setMinimumSize(QtCore.QSize(1000, data.GraphBitMapHeight)) #needed?
+        
+        
+        
+        
         QtCore.QObject.connect(self.ui.bStop, QtCore.SIGNAL("clicked()"), self.StopMeasurement)
         QtCore.QObject.connect(self.ui.bRaiseTrigger, QtCore.SIGNAL("clicked()"), self.RaiseTrigger)
         QtCore.QObject.connect(self.ui.bLowerTrigger, QtCore.SIGNAL("clicked()"), self.LowerTrigger)
@@ -682,7 +681,7 @@ class frmRecordWindow(QMainWindow):
 
     def ZoomIn(self):
         Zoom(+1)
-        data.ChangesInGraph=True #Make sure it only gets refreshed once
+         
         self.update()
         self.UpdateScreen()
         
@@ -690,7 +689,7 @@ class frmRecordWindow(QMainWindow):
 
     def ZoomOut(self):
         Zoom(-1)
-        data.ChangesInGraph=True #Make sure it only gets refreshed once
+         
         self.update()
         self.UpdateScreen()
 
@@ -701,7 +700,7 @@ class frmRecordWindow(QMainWindow):
         self.ui.bLowerTrigger.setEnabled(True)
         if(data.Trigger==data.maxTrigger): self.ui.bRaiseTrigger.setEnabled(False)
         else: self.ui.bRaiseTrigger.setEnabled(True)
-        data.ChangesInGraph=True #Make sure it only gets refreshed once
+         
         self.update() 
         self.UpdateScreen()
         
@@ -712,7 +711,7 @@ class frmRecordWindow(QMainWindow):
         self.ui.bRaiseTrigger.setEnabled(True)
         if(data.Trigger==0): self.ui.bLowerTrigger.setEnabled(False)
         else: self.ui.bLowerTrigger.setEnabled(True)
-        data.ChangesInGraph=True #Make sure it only gets refreshed once
+         
         self.update()
         self.UpdateScreen()
 
@@ -731,6 +730,7 @@ class frmRecordWindow(QMainWindow):
 #        else: 
 #            pass #close
         else: #quick mode, delete file anyway and close
+            StopMeasurement()
             print "Delete logfile: "+data.logfilename
             os.remove(data.logfolder+data.logfilename)
             data.QuickMode=False
@@ -766,12 +766,22 @@ class frmRecordWindow(QMainWindow):
 ###########################################################################
 class frmViewWindow(QMainWindow):
     def __init__(self, parent=None):
+        global Canvas
         QMainWindow.__init__(self, parent)
         if(data.demo==False): self.setAttribute(Qt.WA_Maemo5StackedWindow) # Also set the Stacked Window parameter for every subwindow in the stack
         
         self.ui = Ui_ViewWindow()
         self.ui.setupUi(self)
         
+#        scroller = self.ui.ScrollArea.property("kineticScroller").toPyObject()
+#        scroller.setEnabled(True)
+        
+        self.Canvas = MyCanvas(self.ui.CanvasWidget)
+        
+        self.ui.CanvasWidget.setMinimumSize(QtCore.QSize(1000, data.GraphBitMapHeight)) #needed?
+        
+        
+        
         QtCore.QObject.connect(self.ui.bRaiseTrigger, QtCore.SIGNAL("clicked()"), self.RaiseTrigger)
         QtCore.QObject.connect(self.ui.bLowerTrigger, QtCore.SIGNAL("clicked()"), self.LowerTrigger)
         QtCore.QObject.connect(self.ui.bZoomIn, QtCore.SIGNAL("clicked()"), self.ZoomIn)
@@ -782,13 +792,11 @@ class frmViewWindow(QMainWindow):
         QtCore.QObject.connect(self.ui.bOpen, QtCore.SIGNAL("clicked()"), self.OpenRecord)
         QtCore.QObject.connect(self.ui.bOpenDate, QtCore.SIGNAL("clicked()"), self.OpenDate)
         QtCore.QObject.connect(self.ui.bEditNote, QtCore.SIGNAL("clicked()"), self.EditNote)
-        QtCore.QObject.connect(self.ui.bLeft, QtCore.SIGNAL("clicked()"), self.goLeft)
-        QtCore.QObject.connect(self.ui.bRight, QtCore.SIGNAL("clicked()"), self.goRight)
-        
+#        QtCore.QObject.connect(self.ui.bLeft, QtCore.SIGNAL("clicked()"), self.goLeft)
+#        QtCore.QObject.connect(self.ui.bRight, QtCore.SIGNAL("clicked()"), self.goRight)
         QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL("triggered()"), self.About)
         QtCore.QObject.connect(self.ui.actionShowRecordData, QtCore.SIGNAL("triggered()"), self.ShowRecordData)
-        
-        
+
         
         #Add styles to buttons
         self.ui.bRaiseTrigger.setStyleSheet(data.UIStyle)
@@ -801,8 +809,8 @@ class frmViewWindow(QMainWindow):
         self.ui.bOpen.setStyleSheet(data.UIStyle)
         self.ui.bOpenDate.setStyleSheet(data.UIStyle)
         self.ui.bEditNote.setStyleSheet(data.UIStyle)
-        self.ui.bLeft.setStyleSheet(data.UIStyle)
-        self.ui.bRight.setStyleSheet(data.UIStyle)
+#        self.ui.bLeft.setStyleSheet(data.UIStyle)
+#        self.ui.bRight.setStyleSheet(data.UIStyle)
         
         
         
@@ -817,10 +825,14 @@ class frmViewWindow(QMainWindow):
             self.ui.bZoomOut.setIcon(QIcon(data.app_path+"img/"+"zoom-out.png"))
             self.ui.bRaiseTrigger.setIcon(QIcon(data.app_path+"img/"+"go-up.png"))
             self.ui.bLowerTrigger.setIcon(QIcon(data.app_path+"img/"+"go-down.png"))
-            self.ui.bLeft.setIcon(QIcon(data.app_path+"img/"+"go-previous.png"))
-            self.ui.bRight.setIcon(QIcon(data.app_path+"img/"+"go-next.png"))
+#            self.ui.bLeft.setIcon(QIcon(data.app_path+"img/"+"go-previous.png"))
+#            self.ui.bRight.setIcon(QIcon(data.app_path+"img/"+"go-next.png"))
             self.ui.bEditNote.setIcon(QIcon(data.app_path+"img/"+"kwrite.png"))
 
+
+
+
+
     def UpdateScreen(self):
 #        shortfolder=string.replace(data.logfolder, data.homedir, "~/")
 #        shortfolder=string.replace(shortfolder, "//", "/") #workaround
@@ -869,14 +881,14 @@ class frmViewWindow(QMainWindow):
             self.ui.bNext.setEnabled(True)
             self.ui.bLast.setEnabled(True)
 
-        ScrollbarStartPercent,ScrollbarEndPercent= ScrollbarData()
-        ScrollbarStartPercent=round(ScrollbarStartPercent,  0)
-        ScrollbarEndPercent=round(ScrollbarEndPercent,  0)
-#        print "UpdateScreen,  Scrollbar percent:",  ScrollbarStartPercent,  ScrollbarEndPercent
-        if(ScrollbarStartPercent>0): self.ui.bLeft.setEnabled(True)
-        else: self.ui.bLeft.setEnabled(False)
-        if(ScrollbarEndPercent<100): self.ui.bRight.setEnabled(True)
-        else: self.ui.bRight.setEnabled(False)
+#        ScrollbarStartPercent,ScrollbarEndPercent= ScrollbarData()
+#        ScrollbarStartPercent=round(ScrollbarStartPercent,  0)
+#        ScrollbarEndPercent=round(ScrollbarEndPercent,  0)
+##        print "UpdateScreen,  Scrollbar percent:",  ScrollbarStartPercent,  ScrollbarEndPercent
+#        if(ScrollbarStartPercent>0): self.ui.bLeft.setEnabled(True)
+#        else: self.ui.bLeft.setEnabled(False)
+#        if(ScrollbarEndPercent<100): self.ui.bRight.setEnabled(True)
+#        else: self.ui.bRight.setEnabled(False)
     
     
     
@@ -902,13 +914,22 @@ class frmViewWindow(QMainWindow):
         LoadFileList()
         ProcessData(True)
         data.Xscale=1 #default zoom level
+#        data.Xscale=0
+#        data.GraphStart=max(records.LastIndex-data.arrXscale[data.Xscale]*775, 0)
+        
+#        data.ChangesInGraph=True #Make sure it only gets refreshed once
+
+
+        ShowGraph(self)
+      
+        
+        
+        
+        
+
+        
         
-        data.GraphStart=max(records.LastIndex-data.arrXscale[data.Xscale]*775, 0)
         
-        data.ChangesInGraph=True #Make sure it only gets refreshed once
-        ViewWindowGraph = ViewWindowCanvas(self)
-        ViewWindowGraph.show()
-        self.UpdateScreen()
         
         
     ###########################################################################
@@ -939,14 +960,21 @@ class frmViewWindow(QMainWindow):
         else: self.ui.bZoomIn.setEnabled(True)
         
 #        print "records.LastIndex:",  records.LastIndex, data.arrXscale[data.Xscale]*775
-        data.GraphStart=max(records.LastIndex-data.arrXscale[data.Xscale]*775, 0)
+#        data.GraphStart=max(records.LastIndex-data.arrXscale[data.Xscale]*775, 0)
 #        print "GraphStart:",  data.GraphStart
         
-        data.ChangesInGraph=True #Make sure it only gets refreshed once
-        self.update()
-        self.UpdateScreen()
-
-
+#        data.ChangesInGraph=True #Make sure it only gets refreshed once
+        
+        
+        ShowGraph(self)
+        
+        
+        
+        
+        
+        
+        
+        
 
     ###########################################################################
     ## 
@@ -957,21 +985,21 @@ class frmViewWindow(QMainWindow):
         if(data.Xscale==data.arrXscaleLen-1): self.ui.bZoomOut.setEnabled(False)
         else: self.ui.bZoomOut.setEnabled(True)
         
-        data.GraphStart=max(records.LastIndex-data.arrXscale[data.Xscale]*775, 0)
+#        data.GraphStart=max(records.LastIndex-data.arrXscale[data.Xscale]*775, 0)
         
-        data.ChangesInGraph=True #Make sure it only gets refreshed once
-        self.update()
-        self.UpdateScreen()
+#        data.ChangesInGraph=True #Make sure it only gets refreshed once
         
         
+        ShowGraph(self)
+
+        
     ###########################################################################
     ## 
     ###########################################################################
     def RaiseTrigger(self):   
         MoveTrigger(+1)
-        data.ChangesInGraph=True #Make sure it only gets refreshed once
-        self.update() 
-        self.UpdateScreen()
+        
+        ShowGraph(self)
 
 
     ###########################################################################
@@ -979,35 +1007,43 @@ class frmViewWindow(QMainWindow):
     ###########################################################################
     def LowerTrigger(self):     
         MoveTrigger(-1)
-        data.ChangesInGraph=True #Make sure it only gets refreshed once
-        self.update()
-        self.UpdateScreen()
+        
+        ShowGraph(self)
     
         
-    ###########################################################################
-    ## 
-    ###########################################################################   
-    def goLeft(self):
-        m=600 #data.arrXscale[data.Xscale]*60
-        data.GraphStart=max(data.GraphStart-m, 0)
-        data.ChangesInGraph=True #Make sure it only gets refreshed once
-        self.update()
-        self.UpdateScreen()
-        
-    ###########################################################################
-    ## 
-    ###########################################################################
-    def goRight(self):
-        m=600   #data.arrXscale[data.Xscale]*60
-#        print "records.LastIndex:",  records.LastIndex, data.arrXscale[data.Xscale]*775
-        MaxGraphStart=max(records.LastIndex-data.arrXscale[data.Xscale]*775, 0)
-        data.GraphStart=min(MaxGraphStart,  data.GraphStart+m)
-#        print "goRight MaxGraphStart:",  MaxGraphStart
-#        print "GraphStart:",  data.GraphStart
-
-        data.ChangesInGraph=True #Make sure it only gets refreshed once
-        self.update()
-        self.UpdateScreen()
+#    ###########################################################################
+#    ## 
+#    ###########################################################################   
+#    def goLeft(self):
+#        m=600 #data.arrXscale[data.Xscale]*60
+#        data.GraphStart=max(data.GraphStart-m, 0)
+#        
+#        
+#
+#        self.ui.ScrollArea.ensureVisible(10000, 10000, 0 , 0)
+#        
+#        
+#        data.ChangesInGraph=True #Make sure it only gets refreshed once
+#        self.update()
+#        self.UpdateScreen()
+#        
+#    ###########################################################################
+#    ## 
+#    ###########################################################################
+#    def goRight(self):
+#        m=600   #data.arrXscale[data.Xscale]*60
+##        print "records.LastIndex:",  records.LastIndex, data.arrXscale[data.Xscale]*775
+#        MaxGraphStart=max(records.LastIndex-data.arrXscale[data.Xscale]*775, 0)
+#        data.GraphStart=min(MaxGraphStart,  data.GraphStart+m)
+##        print "goRight MaxGraphStart:",  MaxGraphStart
+##        print "GraphStart:",  data.GraphStart
+#
+#
+#        self.ui.ScrollArea.ensureVisible(10000, 10000, 0 , 0)
+#
+#        data.ChangesInGraph=True #Make sure it only gets refreshed once
+#        self.update()
+#        self.UpdateScreen()
         
         
     ###########################################################################
@@ -1428,14 +1464,13 @@ class frmAlarmTimeWindow(QMainWindow):
     ## 
     ###########################################################################
     def SetAlarm(self):
-        global RecordWindowGraph
         
         InitRecord() #clear all old data
         
 #        print "Set Alarm"
         data.QuickMode=False #run in normal mode        
         
-        RecordWindowGraph = RecordWindowCanvas(RecordWindow)
+#        RecordWindowCanvas = RecordWindowCanvas(RecordWindow)
                 
         try:
             data.AlarmHour=int(self.ui.lstAlarmHour.currentItem().text())
@@ -1478,10 +1513,10 @@ class frmAlarmTimeWindow(QMainWindow):
         SetAlarm() #set alarm for the last possible time
         InitMeasurement()
         
-        RecordWindow.show()
-        AlarmTimeWindow.hide()
-        RecordWindow.UpdateScreenStart()
-        RecordWindowGraph.show()
+#        RecordWindow.show()
+#        AlarmTimeWindow.hide()
+#        RecordWindow.UpdateScreenStart()
+#        RecordWindowCanvas.show()
 
 
 
@@ -1616,7 +1651,7 @@ class DisplayStatusDaemon:
     ## 
     ###########################################################################
     def DisplayStatus(self, *params):
-        global RecordWindowGraph 
+        global RecordWindow
 #        print "1", len(params)
 #        print params
         tmp=str(params)
@@ -1628,57 +1663,88 @@ class DisplayStatusDaemon:
             if(data.run==True): 
                 if(data.debug==1): print "Update screen & graph"
                 RecordWindow.UpdateScreen()
-                data.ChangesInGraph=True
-                RecordWindowGraph.update()
-                
+#                data.ChangesInGraph=True
+                RecordWindow.Canvas.update()
 
-        if(data.debug==1): print "DBUS Daemon => DisplayIsOn:",  data.DisplayIsOn
-        
-        
-        
-        
-        
-        
-        
-        
 
 
 
 
 ###########################################################################
-## Class for drawing the RecordWindowGraph
+## 
 ###########################################################################
-class RecordWindowCanvas(QtGui.QWidget):
+class MyCanvas(QtGui.QWidget):
     def __init__(self, parent):
         QMainWindow.__init__(self, parent)    
-        self.setGeometry(9, 180, 782, data.Ysize+55)
+        self.setGeometry(0, 0, 770, data.GraphBitMapHeight)
+        
+#        print "Create canvas with:",  770,  data.Ysize,  "(Size will change depending on graph len)"
 
-#    ###########################################################################
-    ## 
-    ###########################################################################
-    def paintEvent(self, event):
-        showGraph(self,  QtGui)
-
-
-
-    
-###########################################################################
-# Class for drawing the ViewWindowGraph
-###########################################################################
-class ViewWindowCanvas(QtGui.QWidget):
-    def __init__(self, parent):
-        QMainWindow.__init__(self, parent)    
-        self.setGeometry(9, 100, 782, data.Ysize+55)
 
     ###########################################################################
     ## 
     ###########################################################################
     def paintEvent(self, event):
-        showGraph(self,  QtGui)
+        if(data.DisplayIsOn==False):
+            if(data.debug==1): print "-> Do not redraw, Display is off!"
+            return
+        
+        if(data.ScrollToEnd==True): 
+            if(data.debug==1): print "Set scroll position to:",  data.GraphBitMapLen+10
+            if(data.run==True): RecordWindow.ui.ScrollArea.ensureVisible(data.GraphBitMapLen+100, 0, 0 , 0)
+            else: ViewWindow.ui.ScrollArea.ensureVisible(data.GraphBitMapLen+100, 0, 0 , 0)
+            data.ScrollToEnd=False
+
+#        GenerateGraph(self,  QtGui)
+
+        paint = QtGui.QPainter()
+        paint.begin(self)
+        
+        paint.drawPixmap(0, 0, data.GraphBitMap) #load graph from Bitmap
+
+        paint.end()
 
     
     
+    
+    
+    
+    
+    
+    
+###########################################################################
+## 
+###########################################################################        
+def ShowGraph(self):
+    if(data.DisplayIsOn==False):
+        if(data.debug==1): print "-> Do not update graph, Display is off!"
+        return
+        
+    Xscale=data.arrXscale[data.Xscale]
+#        data.GraphBitMapLen=max((records.LastIndex+5)/Xscale + 2 ,  770)
+    data.GraphBitMapLen=max((records.LastIndex+5)/Xscale + 2 ,  735)
+    data.GraphBitMapHeight=data.Ysize+34
+    
+#    print "GraphBitMapLen:",  data.GraphBitMapLen,  ", GraphBitMapHeight:",  data.GraphBitMapHeight ,  ", Ysize is:", data.Ysize  
+    
+    data.GraphBitMap = QtGui.QPixmap(data.GraphBitMapLen, data.GraphBitMapHeight) #create bitmap for graph
+    
+    GenerateGraph(data.GraphBitMap,  QtGui) # draw graph
+    
+#    ViewWindowCanvas.setGeometry(0, 0, data.GraphBitMapLen, data.GraphBitMapHeight)  #set size of canvas to graph 
+    self.Canvas.setGeometry(0, 0, data.GraphBitMapLen, data.GraphBitMapHeight)  #set size of canvas to graph 
+#    print "Set size of canvas to :",  data.GraphBitMapLen, "x",  data.GraphBitMapHeight
+    
+    self.ui.CanvasWidget.setMinimumSize(data.GraphBitMapLen, data.GraphBitMapHeight)  #set size of canvas widget to graph
 
+    data.ScrollToEnd=True
+    
+    self.ui.CanvasWidget.hide()
+    self.ui.CanvasWidget.show()
+    self.UpdateScreen()
+    
+    
+    
     
     
 ###########################################################################
